==> TIES_openmeetings_1.0.0.zip: ties_moodle/mod/openmeetings/lang/ru/openmeetings.php <==
<?php

$string['openmeetings'] = 'openmeetings';

$string['modulename'] = 'OpenMeetings';
$string['modulenameplural'] = 'OpenMeetings';

$string['whiteboardfieldset'] = '&#1055;&#1088;&#1080;&#1084;&#1077;&#1088;&#1085;&#1099;&#1077; &#1085;&#1072;&#1089;&#1090;&#1088;&#1086;&#1081;&#1082;&#1080;';
$string['whiteboardintro'] = '&#1042;&#1074;&#1077;&#1076;&#1077;&#1085;&#1080;&#1077; &#1074; OpenMeetings';
$string['whiteboardname'] = '&#1053;&#1072;&#1079;&#1074;&#1072;&#1085;&#1080;&#1077; &#1082;&#1086;&#1085;&#1092;&#1077;&#1088;&#1077;&#1085;&#1094;&#1080;&#1080;';

$string['red5host'] = '&#1048;&#1084;&#1103; &#1080;&#1083;&#1080; IP &#1072;&#1076;&#1088;&#1077;&#1089; &#1089;&#1077;&#1088;&#1074;&#1077;&#1088;&#1072; OpenMeetings';
$string['red5port'] = '&#1055;&#1086;&#1088;&#1090; &#1089;&#1077;&#1088;&#1074;&#1077;&#1088;&#1072; OpenMeetings';
$string['openmeetingsAdminUser'] = '&#1048;&#1084;&#1103; &#1072;&#1076;&#1084;&#1080;&#1085;&#1080;&#1089;&#1090;&#1072;&#1090;&#1086;&#1088;&#1072; OpenMeetings';
$string['openmeetingsAdminUserPass'] = '&#1055;&#1072;&#1088;&#1086;&#1083;&#1100; &#1072;&#1076;&#1084;&#1080;&#1085;&#1080;&#1089;&#1090;&#1088;&#1072;&#1090;&#1086;&#1088;&#1072; OpenMeetings';
$string['openmeetingsModuleKeyLabel'] = '&#1050;&#1083;&#1102;&#1095; &#1084;&#1086;&#1076;&#1091;&#1083;&#1103;';
$string['openmeetingsModuleKey'] = '&#1044;&#1086;&#1087;&#1086;&#1083;&#1085;&#1080;&#1090;&#1077;&#1083;&#1100;&#1085;&#1072;&#1103; &#1092;&#1091;&#1085;&#1082;&#1094;&#1080;&#1103;: &#1050;&#1083;&#1102;&#1095; &#1084;&#1086;&#1076;&#1091;&#1083;&#1103; OpenMeetings (&#1076;&#1086;&#1083;&#1078;&#1077;&#1085; &#1073;&#1099;&#1090;&#1100; &#1091;&#1085;&#1080;&#1082;&#1072;&#1083;&#1100;&#1085;&#1099;&#1084; &#1095;&#1090;&#1086;&#1073;&#1099; &#1080;&#1089;&#1087;&#1086;&#1083;&#1100;&#1079;&#1086;&#1074;&#1072;&#1090;&#1100; &#1085;&#1077;&#1089;&#1082;&#1086;&#1083;&#1100;&#1082;&#1086; &#1089;&#1091;&#1097;&#1085;&#1086;&#1089;&#1090;&#1077;&#1081; &#1089; &#1086;&#1076;&#1085;&#1080;&#1084; &#1089;&#1077;&#1088;&#1074;&#1077;&#1088;&#1086;&#1084; OpenMeetings)';

$string['Room_Name'] = '&#1048;&#1084;&#1103; &#1082;&#1086;&#1084;&#1085;&#1072;&#1090;&#1099;';
$string['Room_Type'] = '&#1058;&#1080;&#1087; &#1082;&#1086;&#1084;&#1085;&#1072;&#1090;&#1099;';
$string['Room_Language'] = '&#1071;&#1079;&#1099;&#1082; &#1082;&#1086;&#1084;&#1085;&#1072;&#1090;&#1099;';
$string['Max_User'] = '&#1052;&#1072;&#1082;&#1089;&#1080;&#1084;&#1072;&#1083;&#1100;&#1085;&#1086;&#1077; &#1082;&#1086;&#1083;&#1080;&#1095;&#1077;&#1089;&#1090;&#1074;&#1086; &#1087;&#1086;&#1083;&#1100;&#1079;&#1086;&#1074;&#1072;&#1090;&#1077;&#1083;&#1077;&#1081;';
$string['Wait_for_teacher'] = '&#1054;&#1078;&#1080;&#1076;&#1072;&#1085;&#1080;&#1077; &#1084;&#1086;&#1076;&#1077;&#1088;&#1072;&#1090;&#1086;&#1088;&#1072;';

$string['recordings_label'] = '&#1055;&#1086;&#1083;&#1077; "&#1047;&#1072;&#1087;&#1080;&#1089;&#1100;" &#1080;&#1089;&#1087;&#1086;&#1083;&#1100;&#1079;&#1091;&#1077;&#1090;&#1089;&#1103; &#1090;&#1086;&#1083;&#1100;&#1082;&#1086; &#1076;&#1083;&#1103; &#1082;&#1086;&#1084;&#1085;&#1072;&#1090; &#1090;&#1080;&#1087;&#1072; "&#1047;&#1072;&#1087;&#1080;&#1089;&#1100;". &#1047;&#1072;&#1087;&#1080;&#1089;&#1100; &#1073;&#1091;&#1076;&#1077;&#1090; &#1087;&#1086;&#1082;&#1072;&#1079;&#1072;&#1085;&#1072; &#1074;&#1084;&#1077;&#1089;&#1090;&#1086; &#1082;&#1086;&#1085;&#1092;&#1077;&#1088;&#1077;&#1085;&#1094;&#1080;&#1080;.';
$string['recordings_show'] = '&#1047;&#1072;&#1087;&#1080;&#1089;&#1080;, &#1076;&#1086;&#1089;&#1090;&#1091;&#1087;&#1085;&#1099;&#1077; &#1076;&#1083;&#1103; &#1087;&#1086;&#1082;&#1072;&#1079;&#1072;';
$string['Comment'] = '&#1050;&#1086;&#1084;&#1084;&#1077;&#1085;&#1090;&#1072;&#1088;&#1080;&#1081;';

$string['Conference'] = '&#1050;&#1086;&#1085;&#1092;&#1077;&#1088;&#1077;&#1085;&#1094;&#1080;&#1103; (&#1076;&#1086; 16 &#1091;&#1095;&#1072;&#1089;&#1090;&#1085;&#1080;&#1082;&#1086;&#1074;)';
$string['Audience'] = '&#1040;&#1091;&#1076;&#1080;&#1090;&#1086;&#1088;&#1080;&#1103; (&#1076;&#1086; 32 &#1091;&#1095;&#1072;&#1089;&#1090;&#1085;&#1080;&#1082;&#1086;&#1074;)';
$string['Restricted'] = '&#1042;&#1077;&#1073;-&#1089;&#1077;&#1084;&#1080;&#1085;&#1072;&#1088; (&#1076;&#1086; 150 &#1091;&#1095;&#1072;&#1089;&#1090;&#1085;&#1080;&#1082;&#1086;&#1074;)';
$string['Recording'] = '&#1055;&#1086;&#1082;&#1072;&#1079;&#1072;&#1090;&#1100; &#1079;&#1072;&#1087;&#1080;&#1089;&#1100; (&#1074;&#1099;&#1073;&#1077;&#1088;&#1080;&#1090;&#1077; &#1079;&#1072;&#1087;&#1080;&#1089;&#1100; &#1080;&#1079; &#1074;&#1099;&#1087;&#1072;&#1076;&#1072;&#1102;&#1097;&#1077;&#1075;&#1086; &#1089;&#1087;&#1080;&#1089;&#1082;&#1072;, &#1095;&#1090;&#1086;&#1073;&#1099; &#1087;&#1086;&#1082;&#1072;&#1079;&#1072;&#1090;&#1100; &#1074;&#1084;&#1077;&#1089;&#1090;&#1086; &#1089;&#1086;&#1074;&#1077;&#1097;&#1072;&#1085;&#1080;&#1103;)';

$string['Moderation_Description'] = '(&#1040;&#1076;&#1084;&#1080;&#1085;&#1080;&#1089;&#1090;&#1088;&#1072;&#1090;&#1086;&#1088;&#1099; Moodle, &#1087;&#1088;&#1077;&#1087;&#1086;&#1076;&#1072;&#1074;&#1072;&#1090;&#1077;&#1083;&#1080; &#1080; &#1089;&#1086;&#1079;&#1076;&#1072;&#1090;&#1077;&#1083;&#1080; &#1082;&#1091;&#1088;&#1089;&#1086;&#1074; &#1072;&#1074;&#1090;&#1086;&#1084;&#1072;&#1090;&#1080;&#1095;&#1077;&#1089;&#1082;&#1080; &#1089;&#1090;&#1072;&#1085;&#1086;&#1074;&#1103;&#1090;&#1089;&#1103; &#1084;&#1086;&#1076;&#1077;&#1088;&#1072;&#1090;&#1086;&#1088;&#1072;&#1084;&#1080;)';
$string['Moderation_TYPE_1'] = '&#1059;&#1095;&#1072;&#1089;&#1090;&#1085;&#1080;&#1082;&#1080; &#1076;&#1086;&#1083;&#1078;&#1085;&#1099; &#1076;&#1086;&#1083;&#1078;&#1085;&#1099; &#1078;&#1076;&#1072;&#1090;&#1100; &#1087;&#1086;&#1082;&#1072; &#1087;&#1088;&#1077;&#1087;&#1086;&#1076;&#1072;&#1074;&#1072;&#1090;&#1077;&#1083;&#1100; &#1074;&#1086;&#1081;&#1076;&#1105;&#1090; &#1074; &#1082;&#1086;&#1084;&#1085;&#1072;&#1090;&#1091;';
$string['Moderation_TYPE_2'] = '&#1059;&#1095;&#1072;&#1089;&#1090;&#1085;&#1080;&#1082;&#1080; &#1085;&#1077; &#1076;&#1086;&#1083;&#1078;&#1085;&#1099; &#1078;&#1076;&#1072;&#1090;&#1100; (&#1087;&#1077;&#1088;&#1074;&#1099;&#1081; &#1074;&#1086;&#1096;&#1077;&#1076;&#1096;&#1080;&#1081; &#1089;&#1090;&#1072;&#1085;&#1086;&#1074;&#1080;&#1090;&#1089;&#1103; &#1084;&#1086;&#1076;&#1077;&#1088;&#1072;&#1090;&#1086;&#1088;&#1086;&#1084;)';
$string['Moderation_TYPE_3'] = '&#1050;&#1072;&#1078;&#1076;&#1099;&#1081; &#1091;&#1095;&#1072;&#1089;&#1090;&#1085;&#1080;&#1082; &#1072;&#1074;&#1090;&#1086;&#1084;&#1072;&#1090;&#1080;&#1095;&#1077;&#1089;&#1082;&#1080; &#1089;&#1090;&#1072;&#1085;&#1086;&#1074;&#1080;&#1090;&#1089;&#1089;&#1103; &#1084;&#1086;&#1076;&#1077;&#1088;&#1072;&#1090;&#1086;&#1088;&#1086;&#1084;, &#1082;&#1086;&#1075;&#1076;&#1072; &#1074;&#1093;&#1086;&#1076;&#1080;&#1090; &#1074; &#1082;&#1086;&#1084;&#1085;&#1072;&#1090;&#1091;';

$string['Allow_Recording'] = '&#1056;&#1072;&#1079;&#1088;&#1077;&#1096;&#1080;&#1090;&#1100; &#1079;&#1072;&#1087;&#1080;&#1089;&#1100;?';
$string['Recording_TYPE_1'] = '&#1056;&#1072;&#1079;&#1088;&#1077;&#1096;&#1080;&#1090;&#1100;';
$string['Recording_TYPE_2'] = '&#1047;&#1072;&#1087;&#1088;&#1077;&#1090;&#1080;&#1090;&#1100;';

$string['openmeetingsWebappnameLabel'] = '&#1048;&#1084;&#1103; &#1087;&#1088;&#1080;&#1083;&#1086;&#1078;&#1077;&#1085;&#1080;&#1103; OpenMeetings';
$string['openmeetingsWebappnameDescription'] = '&#1044;&#1086;&#1087;&#1086;&#1083;&#1085;&#1080;&#1090;&#1077;&#1083;&#1100;&#1085;&#1072;&#1103; &#1092;&#1091;&#1085;&#1082;&#1094;&#1080;&#1103;: &#1045;&#1089;&#1083;&#1080; &#1042;&#1099; &#1087;&#1077;&#1088;&#1077;&#1080;&#1084;&#1077;&#1085;&#1086;&#1074;&#1072;&#1083;&#1080; &#1087;&#1088;&#1080;&#1083;&#1086;&#1078;&#1077;&#1085;&#1080;&#1077; OpenMeetings &#1091;&#1082;&#1072;&#1078;&#1080;&#1090;&#1077; &#1077;&#1075;&#1086; &#1085;&#1086;&#1074;&#1086;&#1077; &#1080;&#1084;&#1103; &#1079;&#1076;&#1077;&#1089;&#1100;.';

?>

==> TIES_openmeetings_1.2.0.zip: ties_moodle/mod/openmeetings/lang/ru/openmeetings.php <==
<?php
/*
* Licensed to the Apache Software Foundation (ASF) under one
* or more contributor license agreements.  See the NOTICE file
* distributed with this work for additional information
* regarding copyright ownership.  The ASF licenses this file
* to you under the Apache License, Version 2.0 (the
* "License") +  you may not use this file except in compliance
* with the License.  You may obtain a copy of the License at
*
*   http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing,
* software distributed under the License is distributed on an
* "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
* KIND, either express or implied.  See the License for the
* specific language governing permissions and limitations
* under the License.
*/

$string['openmeetings'] = 'openmeetings';
$string['openmeetings:addinstance'] = 'Add instance of Openmeetings';
$string['openmeetings:becomemoderator'] = 'Become moderator in an Openmeetings Room';

$string['modulename'] = 'OpenMeetings';
$string['modulename_help'] = 'OpenMeetings is a free browser-based software that allows you to set up instantly a conference in the Web. You can use your microphone and/or webcam, share documents on a white board, share your screen or record meetings.<br><br>This Moodle plugin uses Apache OpenMeetings.
<br>You need your own Apache OpenMeetings instance running.<br><br>For more information see: <a href="http://openmeetings.apache.org">http://openmeetings.apache.org</a>';
$string['modulenameplural'] = 'OpenMeetings';

$string['whiteboardfieldset'] = '&#1055;&#1088;&#1080;&#1084;&#1077;&#1088;&#1085;&#1099;&#1077; &#1085;&#1072;&#1089;&#1090;&#1088;&#1086;&#1081;&#1082;&#1080;';
$string['whiteboardintro'] = '&#1042;&#1074;&#1077;&#1076;&#1077;&#1085;&#1080;&#1077; &#1074; OpenMeetings';
$string['whiteboardname'] = '&#1053;&#1072;&#1079;&#1074;&#1072;&#1085;&#1080;&#1077; &#1082;&#1086;&#1085;&#1092;&#1077;&#1088;&#1077;&#1085;&#1094;&#1080;&#1080;';

$string['red5host'] = '&#1048;&#1084;&#1103; &#1080;&#1083;&#1080; IP &#1072;&#1076;&#1088;&#1077;&#1089; &#1089;&#1077;&#1088;&#1074;&#1077;&#1088;&#1072; OpenMeetings';
$string['red5port'] = '&#1055;&#1086;&#1088;&#1090; &#1089;&#1077;&#1088;&#1074;&#1077;&#1088;&#1072; OpenMeetings';
$string['openmeetingsAdminUser'] = '&#1048;&#1084;&#1103; &#1072;&#1076;&#1084;&#1080;&#1085;&#1080;&#1089;&#1090;&#1072;&#1090;&#1086;&#1088;&#1072; OpenMeetings';
$string['openmeetingsAdminUserPass'] = '&#1055;&#1072;&#1088;&#1086;&#1083;&#1100; &#1072;&#1076;&#1084;&#1080;&#1085;&#1080;&#1089;&#1090;&#1088;&#1072;&#1090;&#1086;&#1088;&#1072; OpenMeetings';
$string['openmeetingsModuleKeyLabel'] = '&#1050;&#1083;&#1102;&#1095; &#1084;&#1086;&#1076;&#1091;&#1083;&#1103;';
$string['openmeetingsModuleKey'] = '&#1044;&#1086;&#1087;&#1086;&#1083;&#1085;&#1080;&#1090;&#1077;&#1083;&#1100;&#1085;&#1072;&#1103; &#1092;&#1091;&#1085;&#1082;&#1094;&#1080;&#1103;: &#1050;&#1083;&#1102;&#1095; &#1084;&#1086;&#1076;&#1091;&#1083;&#1103; OpenMeetings (&#1076;&#1086;&#1083;&#1078;&#1077;&#1085; &#1073;&#1099;&#1090;&#1100; &#1091;&#1085;&#1080;&#1082;&#1072;&#1083;&#1100;&#1085;&#1099;&#1084; &#1095;&#1090;&#1086;&#1073;&#1099; &#1080;&#1089;&#1087;&#1086;&#1083;&#1100;&#1079;&#1086;&#1074;&#1072;&#1090;&#1100; &#1085;&#1077;&#1089;&#1082;&#1086;&#1083;&#1100;&#1082;&#1086; &#1089;&#1091;&#1097;&#1085;&#1086;&#1089;&#1090;&#1077;&#1081; &#1089; &#1086;&#1076;&#1085;&#1080;&#1084; &#1089;&#1077;&#1088;&#1074;&#1077;&#1088;&#1086;&#1084; OpenMeetings)';

$string['Room_Name'] = '&#1048;&#1084;&#1103; &#1082;&#1086;&#1084;&#1085;&#1072;&#1090;&#1099;';
$string['Room_Type'] = '&#1058;&#1080;&#1087; &#1082;&#1086;&#1084;&#1085;&#1072;&#1090;&#1099;';
$string['Room_Language'] = '&#1071;&#1079;&#1099;&#1082; &#1082;&#1086;&#1084;&#1085;&#1072;&#1090;&#1099;';
$string['Max_User'] = '&#1052;&#1072;&#1082;&#1089;&#1080;&#1084;&#1072;&#1083;&#1100;&#1085;&#1086;&#1077; &#1082;&#1086;&#1083;&#1080;&#1095;&#1077;&#1089;&#1090;&#1074;&#1086; &#1087;&#1086;&#1083;&#1100;&#1079;&#1086;&#1074;&#1072;&#1090;&#1077;&#1083;&#1077;&#1081;';
$string['Wait_for_teacher'] = '&#1054;&#1078;&#1080;&#1076;&#1072;&#1085;&#1080;&#1077; &#1084;&#1086;&#1076;&#1077;&#1088;&#1072;&#1090;&#1086;&#1088;&#1072;';

$string['recordings_label'] = '&#1055;&#1086;&#1083;&#1077; "&#1047;&#1072;&#1087;&#1080;&#1089;&#1100;" &#1080;&#1089;&#1087;&#1086;&#1083;&#1100;&#1079;&#1091;&#1077;&#1090;&#1089;&#1103; &#1090;&#1086;&#1083;&#1100;&#1082;&#1086; &#1076;&#1083;&#1103; &#1082;&#1086;&#1084;&#1085;&#1072;&#1090; &#1090;&#1080;&#1087;&#1072; "&#1047;&#1072;&#1087;&#1080;&#1089;&#1100;". &#1047;&#1072;&#1087;&#1080;&#1089;&#1100; &#1073;&#1091;&#1076;&#1077;&#1090; &#1087;&#1086;&#1082;&#1072;&#1079;&#1072;&#1085;&#1072; &#1074;&#1084;&#1077;&#1089;&#1090;&#1086; &#1082;&#1086;&#1085;&#1092;&#1077;&#1088;&#1077;&#1085;&#1094;&#1080;&#1080;.';
$string['recordings_show'] = '&#1047;&#1072;&#1087;&#1080;&#1089;&#1080;, &#1076;&#1086;&#1089;&#1090;&#1091;&#1087;&#1085;&#1099;&#1077; &#1076;&#1083;&#1103; &#1087;&#1086;&#1082;&#1072;&#1079;&#1072;';
$string['Comment'] = '&#1050;&#1086;&#1084;&#1084;&#1077;&#1085;&#1090;&#1072;&#1088;&#1080;&#1081;';

$string['Conference'] = '&#1050;&#1086;&#1085;&#1092;&#1077;&#1088;&#1077;&#1085;&#1094;&#1080;&#1103; (&#1076;&#1086; 16 &#1091;&#1095;&#1072;&#1089;&#1090;&#1085;&#1080;&#1082;&#1086;&#1074;)';
$string['Interview'] = 'Interview (2 participants)';
$string['Restricted'] = '&#1042;&#1077;&#1073;-&#1089;&#1077;&#1084;&#1080;&#1085;&#1072;&#1088; (&#1076;&#1086; 150 &#1091;&#1095;&#1072;&#1089;&#1090;&#1085;&#1080;&#1082;&#1086;&#1074;)';
$string['Recording'] = '&#1055;&#1086;&#1082;&#1072;&#1079;&#1072;&#1090;&#1100; &#1079;&#1072;&#1087;&#1080;&#1089;&#1100; (&#1074;&#1099;&#1073;&#1077;&#1088;&#1080;&#1090;&#1077; &#1079;&#1072;&#1087;&#1080;&#1089;&#1100; &#1080;&#1079; &#1074;&#1099;&#1087;&#1072;&#1076;&#1072;&#1102;&#1097;&#1077;&#1075;&#1086; &#1089;&#1087;&#1080;&#1089;&#1082;&#1072;, &#1095;&#1090;&#1086;&#1073;&#1099; &#1087;&#1086;&#1082;&#1072;&#1079;&#1072;&#1090;&#1100; &#1074;&#1084;&#1077;&#1089;&#1090;&#1086; &#1089;&#1086;&#1074;&#1077;&#1097;&#1072;&#1085;&#1080;&#1103;)';

$string['Moderation_Description'] = '(&#1040;&#1076;&#1084;&#1080;&#1085;&#1080;&#1089;&#1090;&#1088;&#1072;&#1090;&#1086;&#1088;&#1099; Moodle, &#1087;&#1088;&#1077;&#1087;&#1086;&#1076;&#1072;&#1074;&#1072;&#1090;&#1077;&#1083;&#1080; &#1080; &#1089;&#1086;&#1079;&#1076;&#1072;&#1090;&#1077;&#1083;&#1080; &#1082;&#1091;&#1088;&#1089;&#1086;&#1074; &#1072;&#1074;&#1090;&#1086;&#1084;&#1072;&#1090;&#1080;&#1095;&#1077;&#1089;&#1082;&#1080; &#1089;&#1090;&#1072;&#1085;&#1086;&#1074;&#1103;&#1090;&#1089;&#1103; &#1084;&#1086;&#1076;&#1077;&#1088;&#1072;&#1090;&#1086;&#1088;&#1072;&#1084;&#1080;)';
$string['Moderation_TYPE_1'] = '&#1059;&#1095;&#1072;&#1089;&#1090;&#1085;&#1080;&#1082;&#1080; &#1076;&#1086;&#1083;&#1078;&#1085;&#1099; &#1076;&#1086;&#1083;&#1078;&#1085;&#1099; &#1078;&#1076;&#1072;&#1090;&#1100; &#1087;&#1086;&#1082;&#1072; &#1087;&#1088;&#1077;&#1087;&#1086;&#1076;&#1072;&#1074;&#1072;&#1090;&#1077;&#1083;&#1100; &#1074;&#1086;&#1081;&#1076;&#1105;&#1090; &#1074; &#1082;&#1086;&#1084;&#1085;&#1072;&#1090;&#1091;';
$string['Moderation_TYPE_2'] = '&#1059;&#1095;&#1072;&#1089;&#1090;&#1085;&#1080;&#1082;&#1080; &#1085;&#1077; &#1076;&#1086;&#1083;&#1078;&#1085;&#1099; &#1078;&#1076;&#1072;&#1090;&#1100; (&#1087;&#1077;&#1088;&#1074;&#1099;&#1081; &#1074;&#1086;&#1096;&#1077;&#1076;&#1096;&#1080;&#1081; &#1089;&#1090;&#1072;&#1085;&#1086;&#1074;&#1080;&#1090;&#1089;&#1103; &#1084;&#1086;&#1076;&#1077;&#1088;&#1072;&#1090;&#1086;&#1088;&#1086;&#1084;)';
$string['Moderation_TYPE_3'] = '&#1050;&#1072;&#1078;&#1076;&#1099;&#1081; &#1091;&#1095;&#1072;&#1089;&#1090;&#1085;&#1080;&#1082; &#1072;&#1074;&#1090;&#1086;&#1084;&#1072;&#1090;&#1080;&#1095;&#1077;&#1089;&#1082;&#1080; &#1089;&#1090;&#1072;&#1085;&#1086;&#1074;&#1080;&#1090;&#1089;&#1089;&#1103; &#1084;&#1086;&#1076;&#1077;&#1088;&#1072;&#1090;&#1086;&#1088;&#1086;&#1084;, &#1082;&#1086;&#1075;&#1076;&#1072; &#1074;&#1093;&#1086;&#1076;&#1080;&#1090; &#1074; &#1082;&#1086;&#1084;&#1085;&#1072;&#1090;&#1091;';

$string['Allow_Recording'] = '&#1056;&#1072;&#1079;&#1088;&#1077;&#1096;&#1080;&#1090;&#1100; &#1079;&#1072;&#1087;&#1080;&#1089;&#1100;?';
$string['Recording_TYPE_1'] = '&#1056;&#1072;&#1079;&#1088;&#1077;&#1096;&#1080;&#1090;&#1100;';
$string['Recording_TYPE_2'] = '&#1047;&#1072;&#1087;&#1088;&#1077;&#1090;&#1080;&#1090;&#1100;';

$string['openmeetingsWebappnameLabel'] = '&#1048;&#1084;&#1103; &#1087;&#1088;&#1080;&#1083;&#1086;&#1078;&#1077;&#1085;&#1080;&#1103; OpenMeetings';
$string['openmeetingsWebappnameDescription'] = '&#1044;&#1086;&#1087;&#1086;&#1083;&#1085;&#1080;&#1090;&#1077;&#1083;&#1100;&#1085;&#1072;&#1103; &#1092;&#1091;&#1085;&#1082;&#1094;&#1080;&#1103;: &#1045;&#1089;&#1083;&#1080; &#1042;&#1099; &#1087;&#1077;&#1088;&#1077;&#1080;&#1084;&#1077;&#1085;&#1086;&#1074;&#1072;&#1083;&#1080; &#1087;&#1088;&#1080;&#1083;&#1086;&#1078;&#1077;&#1085;&#1080;&#1077; OpenMeetings &#1091;&#1082;&#1072;&#1078;&#1080;&#1090;&#1077; &#1077;&#1075;&#1086; &#1085;&#1086;&#1074;&#1086;&#1077; &#1080;&#1084;&#1103; &#1079;&#1076;&#1077;&#1089;&#1100;.';

$string['download_avi'] = '&#1057;&#1082;&#1072;&#1095;&#1072;&#1090;&#1100; .avi';
$string['download_flv'] = '&#1057;&#1082;&#1072;&#1095;&#1072;&#1090;&#1100; .flv';

$string['pluginadministration'] = 'OpenMeetings Administration';
$string['pluginname'] = 'OpenMeetings';
$string['whole_window'] = '&#1047;&#1072;&#1085;&#1103;&#1090;&#1100; &#1074;&#1089;&#1105; &#1086;&#1082;&#1085;&#1086;';
$string['whole_window_type_1'] = '&#1054;&#1090;&#1086;&#1073;&#1088;&#1072;&#1079;&#1080;&#1090;&#1100; &#1074; &#1088;&#1072;&#1084;&#1082;&#1077;';
$string['whole_window_type_2'] = '&#1047;&#1072;&#1085;&#1103;&#1090;&#1100; &#1074;&#1089;&#1105; &#1086;&#1082;&#1085;&#1086;';
$string['openmeetingsProtocol'] = '&#1055;&#1088;&#1086;&#1090;&#1086;&#1082;&#1086;&#1083;';
$string['openmeetingsProtocolDescription'] = '&#1055;&#1088;&#1086;&#1090;&#1086;&#1082;&#1086;&#1083;, &#1082;&#1086;&#1090;&#1086;&#1088;&#1099;&#1081; &#1073;&#1091;&#1076;&#1077;&#1090; &#1080;&#1089;&#1087;&#1086;&#1083;&#1100;&#1079;&#1086;&#1074;&#1072;&#1090;&#1100;&#1089;&#1103; &#1087;&#1088;&#1080; &#1082;&#1086;&#1085;&#1089;&#1090;&#1088;&#1091;&#1080;&#1088;&#1086;&#1074;&#1072;&#1085;&#1080;&#1080; &#1059;&#1056;&#1051; (&#1087;&#1086; &#1091;&#1084;&#1086;&#1083;&#1095;&#1072;&#1085;&#1080;&#1102; http)';
